@@ -68,7 +68,7 @@ const char* Smpte_St0302_ChannelsPositions2(int8u Channels)
 File_Pcm::File_Pcm()
 {
     //Configuration
-    ParserName=__T("PCM");
+    ParserName="PCM";
     #if MEDIAINFO_TRACE
         Trace_Layers_Update(8); //Stream
     #endif //MEDIAINFO_TRACE
