@@ -74,7 +74,7 @@ File_Gxf_TimeCode::File_Gxf_TimeCode()
 :File__Analyze()
 {
     //Configuration
-    ParserName=__T("Time code");
+    ParserName="Time code";
     #if MEDIAINFO_EVENTS
         ParserIDs[0]=MediaInfo_Parser_Gxf;
         StreamIDs_Width[0]=0;
