@@ -67,7 +67,7 @@ File_DtvccTransport::File_DtvccTransport()
 :File__Analyze()
 {
     //Configuration
-    ParserName=__T("DTVCC Transport");
+    ParserName="DTVCC Transport";
     #if MEDIAINFO_EVENTS
         ParserIDs[0]=MediaInfo_Parser_DtvccTransport;
         StreamIDs_Width[0]=1;
@@ -258,6 +258,12 @@ void File_DtvccTransport::Read_Buffer_Continue()
                     //Parsing
                     #if MEDIAINFO_DEMUX
                         Element_Code=Parser_Pos;
+                        /* //Used for debugging (CRC bit is removed of the demuxed stream)
+                        int8u A[2];
+                        A[0] = Buffer[Buffer_Offset+Element_Offset] & 0x7F;
+                        A[1] = Buffer[Buffer_Offset + Element_Offset + 1] & 0x7F;
+                        Demux(A, 2, ContentType_MainStream);
+                        //*/
                         Demux(Buffer+(size_t)(Buffer_Offset+Element_Offset), 2, ContentType_MainStream);
                     #endif //MEDIAINFO_DEMUX
                     if (!Streams[Parser_Pos]->Parser->Status[IsFinished])
