@@ -41,7 +41,7 @@ File_Teletext::File_Teletext()
 :File__Analyze()
 {
     //Configuration
-    ParserName=__T("Teletext");
+    ParserName="Teletext";
     #if MEDIAINFO_EVENTS
         ParserIDs[0]=MediaInfo_Parser_Teletext;
         StreamIDs_Width[0]=2;
@@ -59,6 +59,13 @@ File_Teletext::File_Teletext()
         Parser=NULL;
     #endif
     IsSubtitle=false;
+
+    //Stream
+    Stream_HasChanged=0;
+
+    //Temp
+    PageNumber=0xFF;
+    SubCode=0x3F7F;
 }
 
 //---------------------------------------------------------------------------
@@ -78,12 +85,41 @@ void File_Teletext::Streams_Fill()
 //---------------------------------------------------------------------------
 void File_Teletext::Streams_Finish()
 {
-    for (streams::iterator Stream=Streams.begin(); Stream!=Streams.end(); ++Stream)
+    //Filling when it is from MpegPs
+    //TODO: filter subtitles and non subtitles, some files have normal teletext in subtitles block.
+    if (Parser)
     {
-        Stream_Prepare(Stream_Text);
-        Fill(Stream_Text, StreamPos_Last, Text_Format, IsSubtitle?"Teletext Subtitle":"Teletext");
-        Fill(Stream_Text, StreamPos_Last, Text_ID, Ztring::ToZtring(Stream->first, 16));
+        for (size_t StreamKind=Stream_General+1; StreamKind<Stream_Max; StreamKind++)
+            for (size_t StreamPos=0; StreamPos<Parser->Count_Get((stream_t)StreamKind); StreamPos++)
+            {
+                Stream_Prepare((stream_t)StreamKind);
+                Merge(*Parser, (stream_t)StreamKind, StreamPos_Last, StreamPos);
+            }
+
+        return;
     }
+
+    if (Teletexts && !Teletexts->empty())
+        for (std::map<int16u, teletext>::iterator Teletext=Teletexts->begin(); Teletext!=Teletexts->end(); ++Teletext)
+        {
+            std::map<std::string, Ztring>::iterator Info_Format=Teletext->second.Infos.find("Format");
+            Stream_Prepare((Info_Format!=Teletext->second.Infos.end() && Info_Format->second==__T("Teletext"))?Stream_Other:Stream_Text);
+            Fill(StreamKind_Last, StreamPos_Last, General_ID, Ztring::ToZtring(Teletext->first), true);
+            Fill(StreamKind_Last, StreamPos_Last, General_ID_String, Ztring::ToZtring(Teletext->first), true);
+
+            for (std::map<std::string, ZenLib::Ztring>::iterator Info=Teletext->second.Infos.begin(); Info!=Teletext->second.Infos.end(); ++Info)
+            {
+                if (Retrieve(StreamKind_Last, StreamPos_Last, Info->first.c_str()).empty())
+                    Fill(StreamKind_Last, StreamPos_Last, Info->first.c_str(), Info->second);
+            }
+        }
+    else
+        for (streams::iterator Stream = Streams.begin(); Stream != Streams.end(); ++Stream)
+        {
+            Stream_Prepare(IsSubtitle?Stream_Text:Stream_Other);
+            Fill(StreamKind_Last, StreamPos_Last, General_ID, Ztring::ToZtring(Stream->first, 16));
+            Fill(StreamKind_Last, StreamPos_Last, "Format", IsSubtitle?"Teletext Subtitle":"Teletext");
+        }
 }
 
 //***************************************************************************
@@ -165,12 +201,6 @@ bool File_Teletext::Synched_Test()
 //---------------------------------------------------------------------------
 void File_Teletext::Synched_Init()
 {
-    //Stream
-    Stream_HasChanged=0;
-
-    //Temp
-    PageNumber=0xFF;
-    SubCode=0x3F7F;
 }
 
 //***************************************************************************
@@ -197,6 +227,10 @@ void File_Teletext::Read_Buffer_Unsynched()
                 Stream_HasChanged=0;
             }
         }
+
+    //Unsynching when it is from MpegPs
+    if (Parser)
+        Parser->Open_Buffer_Unsynch();
 }
 
 static inline int8u ReverseBits(int8u c)
@@ -216,7 +250,10 @@ void File_Teletext::Read_Buffer_Continue()
         if (FromMpegPs)
         {
             if (!Status[IsAccepted])
+            {
                 Accept();
+                MustSynchronize=false;
+            }
 
             Skip_B1(                                            "data_identifier");
             while (Element_Offset<Element_Size)
@@ -224,6 +261,8 @@ void File_Teletext::Read_Buffer_Continue()
                 int8u data_unit_id, data_unit_length;
                 Get_B1 (data_unit_id,                           "data_unit_id");
                 Get_B1 (data_unit_length,                       "data_unit_length");
+                if (data_unit_length)
+                {
                 Skip_B1(                                        "field/line");
                 if (data_unit_id==0x03 && data_unit_length==0x2C)
                 {
@@ -235,7 +274,10 @@ void File_Teletext::Read_Buffer_Continue()
                     {
                         Parser=new File_Teletext();
                         Parser->MustSynchronize=false;
+                        Parser->IsSubtitle=data_unit_id==0x03;
+                        Parser->Teletexts=Teletexts;
                         Open_Buffer_Init(Parser);
+                        Parser->Accept(); //Force to be accepted because there is no other synchronization layer (MustSynchronize set to false)
                     }
                     Element_Code=data_unit_id;
                     int8u Temp[2];
@@ -243,11 +285,13 @@ void File_Teletext::Read_Buffer_Continue()
                     Temp[1]=0x55;
                     Demux(Temp, 2, ContentType_MainStream);
                     Demux(Data, 43, ContentType_MainStream);
+                    Parser->FrameInfo=FrameInfo;
                     Open_Buffer_Continue(Parser, Data, 43);
                     Element_Offset+=43;
                 }
                 else
                     Skip_XX(data_unit_length-1,                 "Data");
+                }
             }
         }
     #endif
@@ -519,7 +563,7 @@ void File_Teletext::Header_Parse()
         Element_Info1(Y);
     #endif // MEDIAINFO_TRACE
 
-    Header_Fill_Size(45);
+    Header_Fill_Size(45-(MustSynchronize?0:2));
 
     if (Y==0)
     {
@@ -529,7 +573,7 @@ void File_Teletext::Header_Parse()
             Stream_HasChanged=0;
         }
 
-        if (C[4])
+		if (C[4] && PageNumber!=0xFF)
         {
             stream &Stream=Streams[(X<<8)|PageNumber];
             for (size_t PosY=0; PosY<26; ++PosY)
@@ -575,7 +619,7 @@ void File_Teletext::Data_Parse()
                     case 0x00:  //English
                                 switch(byte)
                                 {
-                                    case 0x23: Uni = __T('\0xA3'); break;
+                                    case 0x23: Uni = __T('\xA3'); break;
                                     case 0x24: Uni = __T('$'); break;
                                     case 0x40: Uni = __T('@'); break;
                                     case 0x5B: Uni = __T('\x2190'); break;
